@@ -104,6 +104,8 @@ class tagObject(object):
         self.__item = item
         self.__spanStart = 0
         self.__spanEnd = 0
+        self.__foundPhrase = ''
+        self.__foundDict = {}
         self.__ConTextCategory = ConTextCategory
         self.__tagID = tagid
         if( scope == None ):
@@ -193,6 +195,12 @@ class tagObject(object):
     def getPhrase(self):
         """return the actual matched phrase used to generate this object"""
         return self.__foundPhrase
+    def setMatchedGroupDictionary(self,mdict):
+        """set the foundDict variable to mdict. This gets the name/value pair for each NAMED group within the regular expression"""
+        self.__foundDict = mdict.copy()
+    def getMatchedGroupDictionary(self):
+        """return a copy of the matched group dictionary"""
+        return self.__foundDict.copy()
     def dist(self,obj):
         """returns the minimum distance from the current object and obj.
         Distance is measured as current start to object end or current end to object start"""
@@ -628,6 +636,7 @@ class ConTextMarkup(nx.DiGraph):
 
             tO.setSpan(i.span())
             tO.setPhrase(i.group())
+            tO.setMatchedGroupDictionary(i.groupdict())
             if( self.getVerbose() ):
                 print u"marked item",tO
             terms.append(tO)
